from setuptools import setup

setup(
      name = "fc_wxy",
      version = "1.0",
      py_modules = ["fc_xy_bigdata"],
      author = "大数据1",
      author_email = "fc@wxy.com",
      description = "大数据1"
)